# 📊 KMeans++

**fastkmeanspp** is a Python package that implements a KMeans clone from `scikit-learn` but with a much faster centroid initialization and optimized for speed with FAISS. It is designed to be a drop-in replacement for `scikit-learn`'s KMeans implementation.

---

## 🚀 Installation

```bash
pip install fastkmeanspp
```

## 📖 Learn More

For tutorials, API reference, visit the official site:  
👉 [fastkmeanspp Documentation](https://felixlaplante0.gitlab.io/fastkmeanspp)